﻿using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using WebApplication45.Data;

// For more information on enabling Web API for empty projects, visit http://go.microsoft.com/fwlink/?LinkID=397860

namespace WebApplication45.Controllers
{
    [Route("api/[controller]")]
    public class PersonsController : Controller
    {
        private readonly PersonContext _personContext;

        public PersonsController(PersonContext personContext)
        {
            _personContext = personContext;
        }

        [HttpGet]
        [ProducesResponseType(typeof(IEnumerable<Person>), (int)HttpStatusCode.OK)]
        public async Task<IActionResult> Get()
        {
            return Ok(await _personContext.Persons.OrderBy(p => p.Name).ToListAsync());
        }

        [HttpGet("{id}")]
        [ProducesResponseType(typeof(Person), (int)HttpStatusCode.OK)]
        public async Task<IActionResult> Get(int id)
        {
            var result = await _personContext.Persons.SingleOrDefaultAsync(p => p.Id == id);
            if (result != null)
            {
                return Ok(result);
            }
            return NotFound();
        }

        [HttpPost]
        [ProducesResponseType(typeof(Person), (int)HttpStatusCode.OK)]
        public async Task<IActionResult> Post([FromBody]Person person)
        {
            _personContext.Add(person);
            await _personContext.SaveChangesAsync();
            return Created("api/persons/" + person.Id, person);
        }

        [HttpPut("{id}")]
        public async Task<IActionResult> Put(int id, [FromBody]Person person)
        {
            if (id != person.Id)
            {
                return BadRequest("Id is incorrect");
            }
            _personContext.Entry(person).State = EntityState.Modified;
            await _personContext.SaveChangesAsync();
            return NoContent();
        }

        [HttpDelete("{id}")]
        public async Task<IActionResult> Delete(int id)
        {
            _personContext.Entry(new Person { Id = id }).State = EntityState.Deleted;
            await _personContext.SaveChangesAsync();
            return Ok();
        }
    }
}
